Description Usage Arguments Value References
View source: R/calculate_ensemble.R
This ensemble approach, unlike cell-wise ensembles, accounts for physical interdependence among grid-points within a GCM projection (Madsen et al. 2017).
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 |
data |
A data.frame with three dimensions – as generated by
|
subset |
A logical vector used to subset gridcells from |
area |
A numeric vector. Its length corresponds to the first dimension
of |
fcentral |
A character string naming the function to calculate a central
tendency across the spatial extent for each GCMs;
one of "mean" or "median". The function is used to calculate the
region-wide (weighted) statistic on which the GCMs are ranked. See
|
funs |
A vector of character strings or of functions. The functions of
the form |
probs |
A numeric vector of probabilities with values in |
... |
Optional arguments passed to |
ties.method |
A character string. Specifies how ties are treated. See
|
variables |
A vector of character strings. A subset of names of the
second dimension of |
reqCSs |
A vector of character strings. A subset of (climate) scenarios
from |
reqMs |
A vector of character strings. A subset of (climate) models
from |
verbose |
A logical value. |
A 4-dimensional, numeric array where the first dimension represents
probs, the second the cells/sites (first dimension of data),
the third the variables, and the fourth the scenarios (ambient plus
reqCSs).
Madsen, M. S., P. L. Langen, F. Boberg, and J. H. Christensen. 2017. Inflated Uncertainty in Multimodel-Based Regional Climate Projections. Geophysical Research Letters 44:11606-11613.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.