whittaker_additive_elements: Whittaker additive elements

Description Usage Details References Examples

View source: R/functions_mathematical.R

Description

Whittaker additive elements

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
whittaker_additive_elements(
  data,
  y = "y",
  w = NULL,
  X1 = "Region",
  X2 = "Shift",
  X3 = "GCM",
  X4 = "RCP",
  family = stats::gaussian()
)

Details

Residual: G(:1234) = g_1234 = residual variation Primaries: G(1:234) = g1_234 = variation uniquely attributable to x1 Secondaries: G(12:34) = g12_34 = variation attributable to x1 or x2 but not to both 3rd order elements: G(123:4) = g123_4 = 4th order elements: G(1234:) = g1234_ =

References

Whittaker, J. 1984. Model Interpretation from the Additive Elements of the Likelihood Function. Journal of the Royal Statistical Society. Series C (Applied Statistics) 33:52-64.

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
## Test code to match up with cement example of Whittaker 1984
## Not run: 
if (requireNamespace("MuMIn")) {
  if (packageVersion("bit") <= "4.0.4") {
    # bit:::chunk.default fails, see #3
    stopifnot(require("ff"))
  }

  probs_cement <- whittaker_additive_elements(
    data = MuMIn::Cement,
    X1 = "X1", X2 = "X2", X3 = "X3", X4 = "X4"
  )$probs
}

#            Residuals           Primary_X1           Primary_X2
#                  1.8                  1.0                  0.1
#           Primary_X3           Primary_X4      Secondary_X1:X2
#                  0.0                  0.0                  3.6
#      Secondary_X1:X3      Secondary_X1:X4      Secondary_X2:X3
#                 29.3                 12.6                  0.9
#      Secondary_X2:X4      Secondary_X3:X4    Tertiary_X1:X2:X3
#                 43.3                  0.4                 -4.1
#    Tertiary_X1:X2:X4    Tertiary_X1:X3:X4    Tertiary_X2:X3:X4
#                  9.1                -11.6                  0.2
# Quartery_X1:X2:X3:X4
#                 13.5

## End(Not run)

DrylandEcology/rSW2analysis documentation built on Nov. 8, 2021, 4:20 p.m.